# FinancialMaths

- A simple financial mathematics calculator.
- Contents are mainly from the actuarial notes (CT1)

## Folder structure:

1. **InterestRateMethods** &rarr; contains the methods from converting {simple, compunding} {interest, discounting} {norminal, effective} rates
2. **InterestRates.py** &rarr; contains the Rate class which is responsible to the common interest methods.
3. **Annuities** &rarr; contains Annuity class with annuity functions.
4. **VaryAnnuity** &rarr; contains Annuity class with annuity functions. Also contiains varying annuity methods.
